@@ -17,11 +17,11 @@ import copy
 import datetime
 import mock
 
+from searchlight.elasticsearch.plugins.base import NotificationBase
 from searchlight.elasticsearch.plugins.glance import metadefs as md_plugin
 import searchlight.tests.unit.utils as unit_test_utils
 import searchlight.tests.utils as test_utils
 
-
 # Metadefinitions
 USER1 = '54492ba0-f4df-4e4e-be62-27f4d76b29cf'
 
@@ -55,6 +55,7 @@ now = datetime.datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%SZ')
 def _namespace_fixture(**kwargs):
     obj = {
         'created_at': now,
+        'updated_at': now,
         'namespace': None,
         'display_name': None,
         'description': None,
@@ -244,8 +245,8 @@ class TestMetadefLoaderPlugin(test_utils.BaseTestCase):
             del ns_copy['objects']
             yield ns_copy
 
-    def test_index_name(self):
-        self.assertEqual('searchlight', self.plugin.get_index_name())
+    def test_resource_group_name(self):
+        self.assertEqual('searchlight', self.plugin.resource_group_name)
 
     def test_document_type(self):
         self.assertEqual('OS::Glance::Metadef',
@@ -348,9 +349,11 @@ class TestMetadefLoaderPlugin(test_utils.BaseTestCase):
     def test_setup_data(self):
         with mock.patch.object(self.plugin, 'get_objects',
                                return_value=self.namespaces) as mock_get:
-            with mock.patch.object(self.plugin, 'save_documents') as mock_save:
+            with mock.patch.object(self.plugin.index_helper,
+                                   'save_documents') as mock_save:
                 self.plugin.setup_data()
-
+                versions = [NotificationBase.get_version(obj)
+                            for obj in self.namespaces]
                 mock_get.assert_called_once_with()
                 mock_save.assert_called_once_with([
                     {
@@ -439,29 +442,29 @@ class TestMetadefLoaderPlugin(test_utils.BaseTestCase):
                             {'name': 'Tag3'},
                         ],
                     }
-                ])
+                ], index=None, versions=versions)
 
     def test_metadef_rbac(self):
         """Test metadefs RBAC query terms"""
         fake_request = unit_test_utils.get_fake_request(
             USER1, TENANT1, '/v1/search'
         )
-        rbac_query_fragment = self.plugin.get_rbac_filter(fake_request.context)
-        expected_fragment = [{
+        rbac_filter = self.plugin.get_query_filters(fake_request.context)
+        expected_fragment = {
             "indices": {
-                "index": "searchlight",
+                "index": "searchlight-search",
                 "no_match_filter": "none",
                 "filter": {
                     "and": [
+                        {"type": {"value": "OS::Glance::Metadef"}},
                         {
                             "or": [
                                 {"term": {"owner": TENANT1}},
                                 {"term": {"visibility": "public"}},
                             ]
-                        },
-                        {"type": {"value": "OS::Glance::Metadef"}}
+                        }
                     ]
                 }
             }
-        }]
-        self.assertEqual(expected_fragment, rbac_query_fragment)
+        }
+        self.assertEqual(expected_fragment, rbac_filter)
